@@ -409,7 +409,8 @@ class _GitLabAPI(object):
         url = self._get_url(api_url, addl_keys)
         #print "%s %s, data=%s" % (request_fn.__name__.upper(), url, str(data))
         try:
-            r = request_fn(url, headers=self._headers, data=data)
+            r = request_fn(url, headers=self._headers, data=data,
+                           **self._requests_kwargs)
         except requests.exceptions.RequestException:
             msg = "'%s' request to '%s' failed" % (request_fn.__name__, url)
             raise exceptions.ConnectionError(msg)
@@ -427,10 +428,17 @@ class _GitLabAPI(object):
 class GitLab(_GitLabAPI):
     """A GitLab API connection."""
 
-    def __init__(self, gitlab_url, token=None, convert_dates=True):
+    def __init__(self, gitlab_url, token=None, convert_dates=True,
+                 ssl_verify=None, ssl_cert=None):
         setattr(_GitLabAPI, '_base_url', gitlab_url + "/api/v3")
         setattr(_GitLabAPI, '_headers', {'PRIVATE-TOKEN': token})
         setattr(_GitLabAPI, '_convert_dates_enabled', convert_dates)
+        requests_kwargs = {}
+        if ssl_verify is not None:
+            requests_kwargs['verify'] = ssl_verify
+        if ssl_cert is not None:
+            requests_kwargs['cert'] = ssl_cert
+        setattr(_GitLabAPI, '_requests_kwargs', requests_kwargs)
 
         for sub_api in _GitLabAPIDefinition.sub_apis:
             cls = _add_api(sub_api, self)
